@@ -167,6 +167,7 @@ class AwsConnectionWrapper(LoggingMixin):
         return service_config.get("endpoint_url", global_endpoint_url)
 
     def __post_init__(self, conn: Connection | AwsConnectionWrapper | _ConnectionMetadata | None) -> None:
+        """Initialize the AwsConnectionWrapper object after instantiation."""
         if isinstance(conn, type(self)):
             # For every field with init=False we copy reference value from original wrapper
             # For every field with init=True we use init values if it not equal default
@@ -346,6 +347,7 @@ class AwsConnectionWrapper(LoggingMixin):
         )
 
     def __bool__(self):
+        """Return the truth value of the AwsConnectionWrapper instance."""
         return self.conn_id is not NOTSET
 
     def _get_credentials(
